@@ -1,6 +1,6 @@
 /*
     zcor.c - Polar map data
-    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2023  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -15,6 +15,9 @@
 #ifdef Z_HAVE_SDL
 
 
+#define _USE_MATH_DEFINES
+#include <math.h>
+
 #include "zcor.h"
 //#include "cordata.h"
 
@@ -23,7 +26,6 @@
 #include "zthread.h"
 #include "zselect.h"
 
-#include <math.h>
 
 struct zcor *gcor = NULL;
 static struct zcor *gcor2 = NULL;
@@ -83,7 +85,7 @@ void zcor_free(struct zcor *cor){
 	if (!cor) return;
 
 
-    if (cor && cor->thread){
+    if (cor->thread){
         cor->thread_break = 1;
 
         //dbg("join cor...\n");
@@ -125,7 +127,7 @@ struct zcor *zcor_calc(double myh, double myw, gchar *locator, struct zselect *z
 void zcors_recalc(double myh, double myw, gchar *locator, struct zselect *zsel, void (*callback)(void), const struct cpoint *file, int cor_items){ 
 	char tmploc[10];
 	hw2loc(tmploc, myh * 180.0/M_PI, myw * 180.0/M_PI, 6);
-    dbg("--------\ncor_recalc('%s')\n", tmploc);
+    //dbg("--------\ncor_recalc('%s')\n", tmploc);
 
 	if (gcor && strcmp(gcor->loc, locator) == 0){
 		//dbg("same locators as gcor\n");
