@@ -171,7 +171,7 @@ int z_sock_printf(int fd, const char *m, ...){
 
 
 
-int z_pipe(int *fds){
+int z_pipe(int fds[2]){
 //#ifndef Z_HAVE_UNISTD_H
 #ifdef WIN32
 	int port, master;
@@ -325,6 +325,9 @@ int z_sock_connect(int sock, union zsockaddr *sa, int timeout_ms){
     int ret, err;
     struct sockaddr *xy = &(sa->sa);
 
+	ret = z_sock_nonblock(sock, 1);
+	if (ret < 0) return ret;
+
     ret = connect(sock, xy, z_sockadr_get_len(sa));
     err = z_sock_errno;
     dbg("connect=%d errno=%d xy=%p\n", ret, err, xy);
